==> code-oss-1.100.0.tar.gz: vscode-1.100.0/src/vs/workbench/contrib/chat/common/promptSyntax/contributions/configMigration.ts <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/

import { assert } from '../../../../../../base/common/assert.js';
import { asBoolean } from '../../../../../../platform/prompts/common/config.js';
import { IWorkbenchContribution } from '../../../../../common/contributions.js';
import { IConfigurationService } from '../../../../../../platform/configuration/common/configuration.js';
import { CONFIG_KEY, PROMPT_LOCATIONS_CONFIG_KEY } from '../../../../../../platform/prompts/common/constants.js';

/**
 * Contribution that migrates the old config setting value to a new one.
 *
 * Note! This is a temporary logic and can be removed on ~2026-04-29.
 */
export class ConfigMigration implements IWorkbenchContribution {
	constructor(
		@IConfigurationService configService: IConfigurationService,
	) {
		const value = configService.getValue(CONFIG_KEY);

		// if setting is not set, nothing to do
		if ((value === undefined) || (value === null)) {
			return;
		}

		// if the setting value is a boolean, we don't need to do
		// anything since it is already a valid configuration value
		if ((typeof value === 'boolean') || (asBoolean(value) !== undefined)) {
			return;
		}

		// in the old setting logic an array of strings was treated
		// as a list of locations, so we need to migrate that
		if (Array.isArray(value)) {

			// copy array values into a map of paths
			const locationsValue: Record<string, boolean> = {};
			for (const filePath of value) {
				if (typeof filePath !== 'string') {
					continue;
				}
				const trimmedValue = filePath.trim();
				if (!trimmedValue) {
					continue;
				}

				locationsValue[trimmedValue] = true;
			}

			configService.updateValue(CONFIG_KEY, true);
			configService.updateValue(PROMPT_LOCATIONS_CONFIG_KEY, locationsValue);
			return;
		}

		// in the old setting logic an object was treated as a map
		// of `location -> boolean`, so we need to migrate that
		if (typeof value === 'object') {
			// sanity check on the contents of value variable - while
			// we've handled the 'null' case above this assertion is
			// here to prevent churn when this block is moved around
			assert(
				value !== null,
				'Object value must not be a null.',
			);

			// copy object values into a map of paths
			const locationsValue: Record<string, boolean> = {};
			for (const [location, enabled] of Object.entries(value)) {
				// if the old location enabled value wasn't a boolean
				// then ignore it as it is not a valid value
				if ((typeof enabled !== 'boolean') || (asBoolean(enabled) === undefined)) {
					continue;
				}

				const trimmedValue = location.trim();
				if (!trimmedValue) {
					continue;
				}

				locationsValue[trimmedValue] = enabled;
			}

			configService.updateValue(CONFIG_KEY, true);
			configService.updateValue(PROMPT_LOCATIONS_CONFIG_KEY, locationsValue);

			return;
		}

		// in the old setting logic a string was treated as a single
		// location path, so we need to migrate that
		if (typeof value === 'string') {
			// sanity check on the contents of value variable - while
			// we've handled the 'boolean' case above this assertion is
			// here to prevent churn when this block is moved around
			assert(
				asBoolean(value) === undefined,
				`String value must not be a boolean, got '${value}'.`,
			);

			configService.updateValue(CONFIG_KEY, true);
			configService.updateValue(PROMPT_LOCATIONS_CONFIG_KEY, { [value]: true });
			return;
		}
	}
}

==> code-oss-1.101.0.tar.gz: vscode-1.101.0/src/vs/workbench/contrib/chat/common/promptSyntax/contributions/configMigration.ts <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/

import { assert } from '../../../../../../base/common/assert.js';
import { ILogService } from '../../../../../../platform/log/common/log.js';
import { asBoolean } from '../../../../../../platform/prompts/common/config.js';
import { IWorkbenchContribution } from '../../../../../common/contributions.js';
import { IConfigurationService } from '../../../../../../platform/configuration/common/configuration.js';
import { CONFIG_KEY, PROMPT_LOCATIONS_CONFIG_KEY } from '../../../../../../platform/prompts/common/prompts.js';

/**
 * Contribution that migrates the old config setting value to a new one.
 *
 * Note! This is a temporary logic and can be removed on ~2026-04-29.
 */
export class ConfigMigration implements IWorkbenchContribution {
	constructor(
		@ILogService private readonly logService: ILogService,
		@IConfigurationService private readonly configService: IConfigurationService,
	) {
		// migrate the old config setting value to a new one
		this.migrateConfig()
			.catch((error) => {
				this.logService.warn('failed to migrate config setting value.', error);
			});
	}

	/**
	 * The main function that implements the migration logic.
	 */
	private async migrateConfig(): Promise<void> {
		const value = await this.configService.getValue(CONFIG_KEY);

		// if setting is not set, nothing to do
		if ((value === undefined) || (value === null)) {
			return;
		}

		// if the setting value is a boolean, we don't need to do
		// anything since it is already a valid configuration value
		if ((typeof value === 'boolean') || (asBoolean(value) !== undefined)) {
			return;
		}

		// in the old setting logic an array of strings was treated
		// as a list of locations, so we need to migrate that
		if (Array.isArray(value)) {

			// copy array values into a map of paths
			const locationsValue: Record<string, boolean> = {};
			for (const filePath of value) {
				if (typeof filePath !== 'string') {
					continue;
				}
				const trimmedValue = filePath.trim();
				if (!trimmedValue) {
					continue;
				}

				locationsValue[trimmedValue] = true;
			}

			await this.configService.updateValue(CONFIG_KEY, true);
			await this.configService.updateValue(PROMPT_LOCATIONS_CONFIG_KEY, locationsValue);
			return;
		}

		// in the old setting logic an object was treated as a map
		// of `location -> boolean`, so we need to migrate that
		if (typeof value === 'object') {
			// sanity check on the contents of value variable - while
			// we've handled the 'null' case above this assertion is
			// here to prevent churn when this block is moved around
			assert(
				value !== null,
				'Object value must not be a null.',
			);

			// copy object values into a map of paths
			const locationsValue: Record<string, boolean> = {};
			for (const [location, enabled] of Object.entries(value)) {
				// if the old location enabled value wasn't a boolean
				// then ignore it as it is not a valid value
				if ((typeof enabled !== 'boolean') || (asBoolean(enabled) === undefined)) {
					continue;
				}

				const trimmedValue = location.trim();
				if (!trimmedValue) {
					continue;
				}

				locationsValue[trimmedValue] = enabled;
			}

			await this.configService.updateValue(CONFIG_KEY, true);
			await this.configService.updateValue(PROMPT_LOCATIONS_CONFIG_KEY, locationsValue);

			return;
		}

		// in the old setting logic a string was treated as a single
		// location path, so we need to migrate that
		if (typeof value === 'string') {
			// sanity check on the contents of value variable - while
			// we've handled the 'boolean' case above this assertion is
			// here to prevent churn when this block is moved around
			assert(
				asBoolean(value) === undefined,
				`String value must not be a boolean, got '${value}'.`,
			);

			await this.configService.updateValue(CONFIG_KEY, true);
			await this.configService.updateValue(PROMPT_LOCATIONS_CONFIG_KEY, { [value]: true });
			return;
		}
	}
}
